This dataset contains the PG-19 language modeling benchmark. It includes a set
of books extracted from the Project Gutenberg books project
(https://www.gutenberg.org), that were published before 1919. It also contains
metadata of book titles and publication dates. PG-19 is over double the size of
the Billion Word benchmark and contains documents that are 20X longer, on
average, than the WikiText long-range language modelling benchmark.

Books are partitioned into a train, validation, and test set. Books metadata is
stored in metadata.csv which contains (book_id, short_book_title,
publication_date, book_link).
